#----------------------- Analysis 'normal' variables ----------------------------

### Install packages 
#install.packages("readxl")
#install.packages("ggeffects")
#install.packages("MASS")
#install.packages("glmmTMB")
#install.packages("car")
#install.packages("ggplot2")
#install.packages("grid")
#install.packages("animation")
#install.packages("magrittr")
#install.packages("dplyr")
#install.packages("vcd")
#install.packages("plyr")
#install.packages("insight")
#install.packages("parameters")
#install.packages("effects")
#install.packages("MuMIn")

### Load the libraries 
library(readxl)
library(ggeffects)
library(MASS) 
library(glmmTMB)
library(car)
library(ggplot2)
library(grid)
library(animation)
library(ggeffects)
library(magrittr) 
library(plyr)
library(dplyr)    
library(vcd)
library(insight)
library(parameters)
library(effects)
library(MuMIn)

### Set working directory 
setwd("E:/HVHL/BSc_Thesis/R")

### Import the database
Database_annual_Norm_Z <- read_excel("Database_Annual_Norm_Z_FINAL.xlsx") # Database with normal annual data, scaled. 

### View the database
View(Database_annual_Norm_Z)

# -------------------------- 'Year' variables ----------------------------------
MydataY<-Database_annual_Norm_Z
nrow(MydataY) #31

data_summary <- function(data, varname, groupnames){
  require(plyr)
  summary_func <- function(x, col){
    c(mean = mean(x[[col]], na.rm=TRUE),
      sd = sd(x[[col]], na.rm=TRUE),
      se= sd(x[[col]], na.rm=TRUE)/sqrt(length(x[[col]])),
      seb=sqrt(mean(x[[col]])/(1-mean(x[[col]]))/length(x[[col]])))
  }
  data_sum<-ddply(data, groupnames, .fun=summary_func,
                  varname)
  data_sum <- rename(data_sum, c("mean" = varname))
  return(data_sum)
}

### Convert data to factor or numeric 
# Random factor: 
MydataYZ$Yearf<-as.factor(MydataYZ$Year)                 # year is the random factor

# Dependent variables: 
MydataYZ$Pregnantn<-as.numeric(MydataYZ$Pregnant)        # converted as numeric for weight analysis
MydataYZ$Pregnantf<-as.factor(MydataYZ$Pregnant)         # converted as factor for pregnancy analysis 

# Independent variables: 
MydataYZ$Feedingf<-as.factor(MydataYZ$Feeding_sites)     # absence (0) or presence (1) of feeding sites 
MydataYZ$Vehiclef<-as.factor(MydataYZ$Vehicle_bin)       # number of vehicles (0 = absent, 1 = present)
MydataYZ$ZD_RDn<-as.numeric(MydataYZ$ZD_RD)              # scaled value of the density of red deer 
MydataYZ$ZD_RD1n<-as.numeric(MydataYZ$ZD_RD1)            # scaled value of the density of red deer in former years (t-1)
MydataYZ$ZD_RD2n<-as.numeric(MydataYZ$ZD_RD2)            # scaled value of the density of red deer in former years (t-2)
MydataYZ$ZD_RD3n<-as.numeric(MydataYZ$ZD_RD3)            # scaled value of the density of red deer in former years (t-3)
MydataYZ$ZD_WBn<-as.numeric(MydataYZ$ZD_WB)              # scaled value of the density of wild boar 
MydataYZ$ZD_Cn<-as.numeric(MydataYZ$ZD_C)                # scaled value of the density of cattle 
MydataYZ$ZRD_shotn<-as.numeric(MydataYZ$ZRD_shot)        # scaled value of the number of red deer shot 
MydataYZ$ZTr_coln<-as.numeric(MydataYZ$ZTr_col)          # scaled value of the number of traffic collisions 
MydataYZ$ZAn_tempn<-as.numeric(MydataYZ$ZAn_Temp)        # scaled value of annual temperature 
MydataYZ$ZAn_rainn<-as.numeric(MydataYZ$ZAn_Rain)        # scaled value of annual precipitation 
MydataYZ$ZForagen<-as.numeric(MydataYZ$ZForage)          # scaled value of suitable foraging area 
MydataYZ$ZNmotor_recn<-as.numeric(MydataYZ$ZNmotor_rec)  # scaled value of the number of non-motorized recreationists 

### sqrt-transformed data 
MydataYZ$ZSQRT_D_RDn<-as.numeric(MydataYZ$ZSQRT_D_RD)
MydataYZ$ZSQRT_D_RD2n<-as.numeric(MydataYZ$ZSQRT_D_RD2)
MydataYZ$ZSQRT_D_RD3n<-as.numeric(MydataYZ$ZSQRT_D_RD3)
MydataYZ$ZSQRT_D_WBn<-as.numeric(MydataYZ$ZSQRT_D_WB)
MydataYZ$ZSQRT_D_Cn<-as.numeric(MydataYZ$ZSQRT_D_C)

# Random factor: 
MydataY$Yearf<-as.factor(MydataY$Year)                   # Year is the random factor 

# Dependent variable: 
MydataY$Preg_meann<-as.numeric(MydataY$Pregnant)         # converted as factor for pregnancy analysis 

# Independent variables; 
MydataY$Feedingf<-as.factor(MydataY$Feeding_sites)       # absence (0) or presence (1) of feeding sites 
MydataY$Vehiclef<-as.factor(MydataY$Vehicle_bin)         # absence (0) or presence (1) of vehicles
MydataY$D_RDn<-as.numeric(MydataY$D_RD)                  # density of red deer 
MydataY$D_RD1n<-as.numeric(MydataY$D_RD1)                # density of red deer in former years (t-1)
MydataY$D_RD2n<-as.numeric(MydataY$D_RD2)                # density of red deer in former years (t-2)
MydataY$D_RD3n<-as.numeric(MydataY$D_RD3)                # density of red deer in former years (t-3)
MydataY$D_WBn<-as.numeric(MydataY$D_WB)                  # density of wild boar 
MydataY$D_Cn<-as.numeric(MydataY$D_C)                    # density of cattle 
MydataY$RD_shotn<-as.numeric(MydataY$RD_shot)            # number of red deer shot 
MydataY$Tr_coln<-as.numeric(MydataY$Tr_col)              # number of traffic collisions 
MydataY$An_tempn<-as.numeric(MydataY$An_Temp)            # annual temperature 
MydataY$An_rainn<-as.numeric(MydataY$An_Rain)            # annual precipitation 
MydataY$Foragen<-as.numeric(MydataY$Forage)              # suitable foraging area 
MydataY$Nmotor_recn <- as.numeric(MydataY$Nmotor_rec)    # number of non-motorized recreationists

### Transformed data
MydataY$SQRT_D_RDn<-as.numeric(MydataY$SQRT_D_RD)
MydataY$SQRT_D_RD2n<-as.numeric(MydataY$SQRT_D_RD2)
MydataY$SQRT_D_RD3n<-as.numeric(MydataY$SQRT_D_RD3)
MydataY$SQRT_D_WBn<-as.numeric(MydataY$SQRT_D_WB)
MydataY$SQRT_D_Cn<-as.numeric(MydataY$SQRT_D_C)

#------------------------------ Data exploration -------------------------------
### Missing values?
colSums(is.na(MydataY))

### Collinearity between predictors (VIF)

# Global Model (A)
modYA <- lm(Preg_meann ~ sqrt(D_RDn) + D_RD1n + sqrt(D_RD2n) + sqrt(D_RD3n) + RD_shotn + sqrt(D_Cn) + Tr_coln + sqrt(D_WBn) + An_rainn + An_tempn + Foragen + Nmotor_recn, 
            data = MydataY)
vif(modYA)

# Model B 
modYB <- lm(Preg_meann ~ sqrt(D_RDn) + D_RD1n + sqrt(D_RD2n) + sqrt(D_RD3n) + RD_shotn + Tr_coln + sqrt(D_WBn) + An_rainn + An_tempn + Foragen + Nmotor_recn, 
            data = MydataY)
vif(modYB)

# Model C 
modYC <- lm(Preg_meann ~ sqrt(D_RDn) + D_RD1n + sqrt(D_RD2n) + sqrt(D_RD3n) + Tr_coln + sqrt(D_WBn) + An_rainn + An_tempn + Foragen + Nmotor_recn, 
            data = MydataY)
vif(modYC)

# Model D 
modYD <- lm(Preg_meann ~ sqrt(D_RDn) + sqrt(D_RD2n) + sqrt(D_RD3n) + Tr_coln + sqrt(D_WBn) + An_rainn + An_tempn + Foragen + Nmotor_recn, 
            data = MydataY)
vif(modYD)

# Model E 
modYE <- lm(Preg_meann ~ sqrt(D_RDn) + sqrt(D_RD2n) + sqrt(D_RD3n) + Tr_coln + An_rainn + An_tempn + Foragen + Nmotor_recn, 
            data = MydataY)
vif(modYE)

### Correlation between independent variables 

#An_tempn vs An_Rainn (annual temperature x annual rain)
cor(MydataY$An_tempn, MydataY$An_rainn)
#0.327818

# Tr_coln vs Nmotor_recn (traffic collisions x non-motorised recreation)
cor(MydataY$Tr_coln, MydataY$Nmotor_recn)
#0.5922408

#sqrt(D_RD2n) vs sqrt(D_RD3n) (sqrt density red deer (-2) x sqrt density red deer (-3) 
cor(MydataY$SQRT_D_RD2n, MydataY$SQRT_D_RD3n)
# 0.6772992

# Tr_coln and sqrt(D_RD2n) were removed based on correlations. 

# ---------------- Pregnancy analysis with 'normal' variables -----------------

### Set working directory
setwd("E:/BSc Thesis/R")

### Import the database 
Database_animal_Norm_Z <- read_excel("Database_animal_Norm_Z_FINAL.xlsx")

### View the database
View(Database_animal_Norm_Z)

MydataA<-Database_animal_Norm_Z
nrow(MydataA) #261 (mast removed)

data_summary <- function(data, varname, groupnames){
  require(plyr)
  summary_func <- function(x, col){
    c(mean = mean(x[[col]], na.rm=TRUE),
      sd = sd(x[[col]], na.rm=TRUE),
      se= sd(x[[col]], na.rm=TRUE)/sqrt(length(x[[col]])),
      seb=sqrt(mean(x[[col]])/(1-mean(x[[col]]))/length(x[[col]])))
  }
  data_sum<-ddply(data, groupnames, .fun=summary_func,
                  varname)
  data_sum <- rename(data_sum, c("mean" = varname))
  return(data_sum)
}

### Transform data to factor or numeric 
# Same variables shown below are also used for the weight analysis 

nrow(MydataA)#261

# Random factor: 
MydataA$Yearf<-as.factor(MydataA$Year) 

# Dependent variable: 
MydataA$Pregnantf<-as.factor(MydataA$Pregnant)
MydataA$Pregnantn<-as.numeric(MydataA$Pregnant)

# Independent variables: 
MydataA$Feedingf<-as.factor(MydataA$Feeding_sites)
MydataA$Vehiclef<-as.factor(MydataA$Vehicle_bin)
MydataA$Weightn<-as.numeric(MydataA$Weight)
MydataA$Agen<-as.numeric(MydataA$Age)
MydataA$D_RDn<-as.numeric(MydataA$D_RD)
MydataA$D_RD1n<-as.numeric(MydataA$D_RD1)
MydataA$D_RD2n<-as.numeric(MydataA$D_RD2)
MydataA$D_RD3n<-as.numeric(MydataA$D_RD3)
MydataA$D_WBn<-as.numeric(MydataA$D_WB)
MydataA$D_Cn<-as.numeric(MydataA$D_C)
MydataA$RD_shotn<-as.numeric(MydataA$RD_shot)
MydataA$Tr_coln<-as.numeric(MydataA$Tr_col)
MydataA$An_tempn<-as.numeric(MydataA$An_Temp)
MydataA$An_rainn<-as.numeric(MydataA$An_Rain)
MydataA$Foragen<-as.numeric(MydataA$Forage)
MydataA$Nmotor_recn<-as.numeric(MydataA$Nmotor_rec)

### Sqrt transformed data
MydataA$SQRT_D_RDn<-as.numeric(MydataA$SQRT_D_RD)
MydataA$SQRT_D_RD2n<-as.numeric(MydataA$SQRT_D_RD2)
MydataA$SQRT_D_RD3n<-as.numeric(MydataA$SQRT_D_RD3)
MydataA$SQRT_D_WBn<-as.numeric(MydataA$SQRT_D_WB)
MydataA$SQRT_D_Cn<-as.numeric(MydataA$SQRT_D_C)
MydataA$SQRT_Agen<-as.numeric(MydataA$SQRT_Age)

MydataA$Agen_sqn <- MydataA$Agen^2

#------------------------------ Data exploration -------------------------------

### Missing values?
colSums(is.na(MydataA))

### Relationships Y vs X
# Relation predictors and dependent variable passage
# Simple logistic regression (passage ~ predictor) and  corresponding (loess+errorbar) 

# SQRT_Agen
ModPAge <- glmmTMB(Pregnantf ~ sqrt(Agen),
                   family = "binomial",
                   data = MydataA)

summary(ModPAge)
Anova(ModPAge)
AIC(ModPAge)

exp(-0.02275) #exp(Estimate)

plot(predictorEffect("Agen", ModPAge))

plot(predictorEffects(ModPAge), main="",
     rug=TRUE,lines=list(col="black"), 
     axes=list(y=list(lab="Pregnancy rate",ticks=list(at=c(0.40,0.50,0.60,0.70,0.80,0.90,0.95))),
               x=list(rotate=0, 
                      Agen=list(lab="Age (years)",ticks=list(at=c(0,2,4,6,8,10,12,14,16))))))

ggplot(MydataA, aes(y=Pregnantn,x=Agen))+geom_smooth(method=loess) 

# Weightn
ModPweight <- glmmTMB(Pregnantf ~ Weightn,
                      family = "binomial",
                      data = MydataA)                                                                                        
summary(ModPweight)
Anova(ModPweight)
AIC(ModPweight)

exp(0.12300) #exp(Estimate)

plot(predictorEffect("Weightn", ModPweight))

plot(predictorEffect("Weightn", ModPweight),add.data=TRUE)
plot(predictorEffects(ModPweight), main="",
     rug=TRUE,lines=list(col="black"),
     axes=list(y=list(lab="Pregnancy rate",ticks=list(at=c(0,0.1,0.3,0.5,0.7,0.9,0.99))),
               x=list(rotate=0, 
                      Weightn=list(lab="Bodyweight (kg)",ticks=list(at=c(40,50,60,70,80))))))

ggplot(MydataA, aes(y=Pregnantn,x=Weightn))+geom_smooth(method=loess)

# sqrt(D_RDn)
ModDPreddeer <- glmmTMB(Pregnantf ~ SQRT_D_RDn,
                       family = "binomial",
                       data = MydataA)
summary(ModDPreddeer)
Anova(ModDPreddeer)
AIC(ModDPreddeer)

exp(-0.2566) #exp(Estimate)

plot(predictorEffect("SQRT_D_RDn", ModDPreddeer))

plot(predictorEffects(ModDPreddeer), main="",
     rug=TRUE,lines=list(col="black"), 
     axes=list(y=list(lab="Pregnancy rate",ticks=list(at=c(0.65,0.70,0.75,0.80,0.85,0.90,0.96))),
               x=list(rotate=0, 
                      SQRT_D_RDn=list(lab="Density Red Deer",ticks=list(at=c(1.4,1.5,1.6,1.7,1.8))))))

ggplot(MydataA, aes(y=Pregnantn,x=SQRT_D_RDn))+geom_smooth(method=loess) 

# SQRT_D_RD3n
ModDPreddeer3 <- glmmTMB(Pregnantf ~ SQRT_D_RD3n,
                        family = "binomial",
                        data = MydataA)
summary(ModDPreddeer3)
Anova(ModDPreddeer3)
AIC(ModDPreddeer3)

exp(0.5755) #exp(Estimate)

plot(predictorEffect("SQRT_D_RD3n", ModDPreddeer3))

plot(predictorEffects(ModDPreddeer3), main="",
     rug=TRUE,lines=list(col="black"),
     axes=list(y=list(lab="Pregnancy rate",ticks=list(at=c(0.65,0.70,0.75,0.80,0.85,0.90,0.95,0.97))),
               x=list(rotate=0, 
                      SQRT_D_RD3n=list(lab="Density Red Deer t-3",ticks=list(at=c(1.4,1.5,1.6,1.7,1.8))))))

ggplot(MydataA, aes(y=Pregnantn,x=SQRT_D_RD3n))+geom_smooth(method=loess)

# An_rainn
ModPAnrain <- glmmTMB(Pregnantf ~ An_rainn,
                    family = "binomial",
                    data = MydataA)
summary(ModPAnrain)
Anova(ModPAnrain)
AIC(ModPAnrain)

exp(-0.9009) #exp(Estimate)

plot(predictorEffect("An_rainn", ModPAnrain))

plot(predictorEffects(ModPAnrain), main="",
     rug=TRUE,lines=list(col="black"), 
     axes=list(y=list(lab="Pregnancy rate",ticks=list(at=c(0.65,0.70,0.75,0.80,0.85,0.90,0.96))),
               x=list(rotate=0, 
                      An_rainn=list(lab="Annual precipitation (mm)",ticks=list(at=c(1.8,2.0,2.2,2.4,2.6,2.8,3.0))))))

ggplot(MydataA, aes(y=Pregnantn,x=An_rainn))+geom_smooth(method=loess)

# An_tempn
ModPAntemp <- glmmTMB(Pregnantn ~ An_tempn,
                      family = "binomial",
                     data = MydataA)

summary(ModPAntemp)
Anova(ModPAntemp)
AIC(ModPAntemp)

exp(-0.04059) #exp(Estimate)

plot(predictorEffect("An_tempn", ModPAntemp))

plot(predictorEffects(ModPAntemp), main="",
     rug=TRUE,lines=list(col="black"),
     axes=list(y=list(lab="Pregnancy rate",ticks=list(at=c(0.65,0.70,0.75,0.80,0.85,0.90,0.97))),
               x=list(rotate=0, 
                      An_tempn=list(lab="Annual temperature (Degrees Celsius)",ticks=list(at=c(8.0,8.5,9.0,9.5,10.0,10.5,11.0))))))

ggplot(MydataA, aes(y=Pregnantn,x=An_tempn))+geom_smooth(method=loess) 

# Foragen
ModPForage <- glmmTMB(Pregnantf ~ Foragen,
                      family = "binomial",
                      data = MydataA)
summary(ModPForage)
Anova(ModPForage)
AIC(ModPForage)

exp(0.26762) #exp(Estimate)

plot(predictorEffect("Foragen", ModPForage))

plot(predictorEffects(ModPForage), main="",
     rug=TRUE,lines=list(col="black"), 
     axes=list(y=list(lab="Pregnancy rate",ticks=list(at=c(0.5,0.6,0.7,0.8,0.9,0.97))),
               x=list(rotate=0, 
                      Foragen=list(lab="Available foraging habitat",ticks=list(at=c(62,63,64,65,66,67,68,69))))))


ggplot(MydataA, aes(y=Pregnantn,x=Foragen))+geom_smooth(method=loess)

# Nmotor_recn
ModPNmotor <- glmmTMB(Pregnantf ~ Nmotor_recn,
                      family = "binomial",
                      data = MydataA)
summary(ModPNmotor)
Anova(ModPNmotor)
AIC(ModPNmotor)

exp(-0.7250) #exp(Estimate)

plot(predictorEffect("Nmotor_recn", ModPNmotor))

plot(predictorEffects(ModPNmotor), main="",
     rug=TRUE,lines=list(col="black"),
     axes=list(y=list(lab="Pregnancy rate",ticks=list(at=c(0.40,0.50,0.60,0.70,0.80,0.90,0.96))),
               x=list(rotate=0, 
                      Nmotor_recn=list(lab="Non-motorized recreation",ticks=list(at=c(-1.0,-1.5,-1.0,0.0,0.5,1.0,1.5,2.0))))))

ggplot(MydataA,aes(y=Pregnantn,x=Nmotor_recn))+geom_smooth(method=loess)

# Vehicle
ModPvehicle <- glmmTMB(Pregnantf ~ Vehiclef,
                       family = "binomial",
                       data = MydataA)
summary(ModPvehicle)
Anova(ModPvehicle)
AIC(ModPvehicle)

exp(-0.01506) #exp(Estimate)

# Feeding
ModPFeeding <- glmmTMB(Pregnantf ~ Feedingf,
                       family = "binomial",
                       data = MydataA)
summary(ModPFeeding)
Anova(ModPFeeding)
AIC(ModPFeeding)

exp(1.0164) #exp(Estimate)

# ---------------------- Testing Putman's interactions ------------------------

### Interaction SQRT_D_RDn x SQRT_Agen
ModPRD_Age <- glmmTMB(Pregnantf ~ SQRT_D_RDn*SQRT_Agen,
                        family = "binomial",
                        data = MydataA)
summary(ModPRD_Age)
Anova(ModPRD_Age)
AIC(ModPRD_Age)

exp(1.609) #exp(Estimate)

plot(allEffects(ModPRD_Age), pages = 1)

### Interaction SQRT_D_RDn x Weightn 
ModPRD_Weight <- glmmTMB(Pregnantf ~ SQRT_D_RDn*Weightn,
                      family = "binomial",
                      data = MydataA)
summary(ModPRD_Weight)
Anova(ModPRD_Weight)
AIC(ModPRD_Weight)

exp(0.11344) #exp(Estimate)

plot(allEffects(ModPRD_Weight), pages = 1)

### Interaction SQRT_Agen x Weightn 
ModPAge_Weight <- glmmTMB(Pregnantf ~ SQRT_Agen*Weightn,
                         family = "binomial",
                         data = MydataA)
summary(ModPAge_Weight)
Anova(ModPAge_Weight)
AIC(ModPAge_Weight)

exp(-0.06628) #exp(Estimate)

plot(allEffects(ModPAge_Weight), pages = 1)

# ------------------------------ Data analysis ---------------------------------

### Global model
ModP1<- glmmTMB(Pregnantf ~ sqrt(Agen) + Weightn + sqrt(D_RDn) + sqrt(D_RD3n) + An_rainn + An_tempn + Vehiclef + Foragen + Nmotor_recn, REML = FALSE,
               family = "binomial",
               data = MydataA)
summary(ModP1)
Anova(ModP1)
AIC(ModP1)  
nrow(MydataA) #261

model_parameters(ModP1, exponentiate = TRUE)

ModP0 <- glmmTMB(Pregnantf ~Vehiclef+Nmotor_recn,REML = FALSE,
                family = "binomial",
                data = MydataA)

stepAIC(ModP1, direction="both", scope = list(lower = ModP0))

# T opmodel stepAIC = Pregnantf ~ sqrt(Agen) + Weightn + Vehiclef + Nmotor_recn, AIC= 173.59

### Drop 1 

# Model A 
ModP1A<- glmmTMB(Pregnantf ~ sqrt(Agen) + Weightn + sqrt(D_RDn) + sqrt(D_RD3n) + An_rainn + An_tempn + Vehiclef + Foragen + Nmotor_recn, REML = FALSE,
                 family = "binomial",
                 data = MydataA)
drop1(ModP1A)

# Model B 
ModP1B<- glmmTMB(Pregnantf ~ sqrt(Agen) + Weightn + sqrt(D_RDn) + An_rainn + An_tempn + Vehiclef + Foragen + Nmotor_recn, REML = FALSE,
                 family = "binomial",
                 data = MydataA)
drop1(ModP1B)

# Model C 
ModP1C<- glmmTMB(Pregnantf ~ sqrt(Agen) + Weightn + sqrt(D_RDn) + An_rainn + Vehiclef + Foragen + Nmotor_recn, REML = FALSE,
                 family = "binomial",
                 data = MydataA)
drop1(ModP1C)

# Model D 
ModP1D<- glmmTMB(Pregnantf ~ sqrt(Agen) + Weightn + An_rainn + Vehiclef + Foragen + Nmotor_recn, REML = FALSE,
                 family = "binomial",
                 data = MydataA)
drop1(ModP1D)

# Model E 
ModP1E<- glmmTMB(Pregnantf ~ sqrt(Agen) + Weightn + Vehiclef + Foragen + Nmotor_recn, REML = FALSE,
                 family = "binomial",
                 data = MydataA)
drop1(ModP1E)

# Model F 
ModP1F<- glmmTMB(Pregnantf ~ sqrt(Agen) + Weightn + Vehiclef + Nmotor_recn, REML = FALSE,
                 family = "binomial",
                 data = MydataA)
drop1(ModP1F)

# Final AIC = 173.59 
# Final model = sqrt(Agen) + Weightn + Vehiclef + Nmotor_recn 

### Final model pregnancy 
ModP2 <- glmmTMB(Pregnantf ~ sqrt(Agen) + Weightn + Vehiclef + Nmotor_recn, REML = FALSE,
                 family = "binomial",
                 data = MydataA)

summary(ModP2)
Anova(ModP2)
AIC(ModP2)

model_parameters(ModP2, exponentiate = TRUE)

plot(allEffects(ModP2), pages = 1)

plot(allEffects(ModP2),add.data= TRUE, selection = 2, main ="",  
     colors = "black", rug = FALSE,
     xlab="Bodyweight (kg)",
     axes=list(y=list(lab="Pregnancy rate",ticks=list(at=c(0,0.1,0.3,0.5,0.7,0.9,0.99)))))


plot(allEffects(ModP2),add.data= TRUE, selection = 4, main ="",  
     colors = "black", rug = FALSE,
     xlab="Non-motorized recreation",
     axes=list(y=list(lab="Pregnancy rate",ticks=list(at=c(0.0,1,0.3,0.5,0.7,0.9,0.98)))))

r.squaredGLMM(ModP2)

library(lmerTest)

ModW3<- lmer(Pregnantf ~ sqrt(Agen) + Weightn + Vehiclef + Nmotor_recn,
             family = "binomial",
             data = MydataA)

### Quick validation of Topmodel 

# install.packages("DHARMa")
library(DHARMa)

resP = simulateResiduals(ModP2)
plot(res, rank=T) 
plotResiduals(res) 
testDispersion(res)  
testZeroInflation(res) 

### Residuals 

resP = simulateResiduals(ModW2)

#Included in model: 

# SQRT_Agen
plotResiduals(resP, form = MydataA$SQRT_Agen, rank = T)
plotResiduals(resP, form = MydataA$SQRT_Agen, rank = FALSE)

# Weightn: 
plotResiduals(resP, form = MydataA$Weightn, rank = T)
plotResiduals(resP, form = MydataA$Weightn, rank = FALSE)

# Nmotor_recn
plotResiduals(resP, form = MydataA$Nmotor_recn, rank = T)
plotResiduals(resP, form = MydataA$Nmotor_recn, rank = FALSE)

# Vehiclef
plotResiduals(resP, form = MydataA$Vehiclef)

# Not included in model: 

# SQRT_D_RDn
plotResiduals(resP, form = MydataA$SQRT_D_RDn, rank = T)
plotResiduals(resP, form = MydataA$SQRT_D_RDn, rank = FALSE)

# SQRT_D_RD3n
plotResiduals(resP, form = MydataA$SQRT_D_RD3n, rank = T)
plotResiduals(resP, form = MydataA$SQRT_D_RD3n, rank = FALSE)

# An_rainn
plotResiduals(resP, form = MydataA$An_rainn, rank = T)
plotResiduals(resP, form = MydataA$An_rainn, rank = FALSE)

# An_tempn
plotResiduals(resP, form = MydataA$An_tempn, rank = T)
plotResiduals(resP, form = MydataA$An_tempn, rank = FALSE)

# Foragen
plotResiduals(resP, form = MydataA$Foragen, rank = T)
plotResiduals(resP, form = MydataA$Foragen, rank = FALSE)

# ----------------- Weight analysis with 'normal' variables --------------------

# --------------------------- Data exploration --------------------------------
### Relationships Y vs X
# Relation predictors and dependent variable passage
# Simple logistic regression (passage ~ predictor) and  corresponding (loess+errorbar) 

### Agen
ModWAge <- glmmTMB(Weightn ~ poly(Agen,degree=2,raw=TRUE) + (1|Year),
                   data = MydataA)
summary(ModWAge)
Anova(ModWAge)
AIC(ModWAge)

exp(-0.2632)#exp(Estimate)

plot(predictorEffect("Agen", ModWAge))

plot(predictorEffects(ModWAge), main="",
     rug=TRUE,lines=list(col="black"), 
     axes=list(y=list(lab="Bodyweight (kg)",ticks=list(at=c(40,45,50,55,60,65,70,75,80,85))),
               x=list(rotate=0, 
                      Agen=list(lab="Age (years)",ticks=list(at=c(0,2,4,6,8,10,12,14,16))))))

ggplot(MydataA, aes(y=Weightn,x=Agen))+geom_smooth(method=loess)

### SQRT_D_RDn
ModDWreddeer <- glmmTMB(Weightn ~ SQRT_D_RDn,
                        data = MydataA)
summary(ModDWreddeer)
Anova(ModDWreddeer)
AIC(ModDWreddeer)

exp(-11.892) #exp(Estimate)

plot(predictorEffect("SQRT_D_RDn", ModDWreddeer))

plot(predictorEffects(ModDWreddeer), main="",
     rug=FALSE,lines=list(col="black"), 
     axes=list(y=list(lab="Bodyweight (kg)",ticks=list(at=c(40,45,50,55,60,65,70,75,80,85))),
               x=list(rotate=0, 
                      SQRT_D_RDn=list(lab="Density red deer",ticks=list(at=c(0,1.2,1.3,1.4,1.5,1.6,1.7,1.8,2))))))

ggplot(MydataA, aes(y=Weightn,x=SQRT_D_RDn))+geom_smooth(method=loess) 

### SQRT_D_RD3n
ModDWreddeer3 <- glmmTMB(Weightn ~ SQRT_D_RD3n,
                        data = MydataA)
summary(ModDWreddeer3)
Anova(ModDWreddeer3)
AIC(ModDWreddeer3)

exp(3.053) #exp(Estimate)

plot(predictorEffect("SQRT_D_RD3n", ModDWreddeer3))

plot(predictorEffects(ModDWreddeer3), main="",
     rug=FALSE,lines=list(col="black"), 
     axes=list(y=list(lab="Bodyweight (kg)",ticks=list(at=c(55,56,57,58,59,60,61,62,63,64,65,66))),
               x=list(rotate=0, 
                      SQRT_D_RD3n=list(lab="Density red deer t-3",ticks=list(at=c(0,1.2,1.3,1.4,1.5,1.6,1.7,1.8,2))))))

ggplot(MydataA, aes(y=Weightn,x=SQRT_D_RD3n))+geom_smooth(method=loess)

### An_rain
ModWAnrain <- glmmTMB(Weightn ~ An_rainn,
                    data = MydataA)
summary(ModWAnrain)
Anova(ModWAnrain)
AIC(ModWAnrain)

exp(-3.641) #exp(Estimate)

plot(predictorEffect("An_rainn", ModWAnrain))

plot(predictorEffects(ModWAnrain), main="",
     rug=TRUE,lines=list(col="black"), 
     axes=list(y=list(lab="Bodyweight (kg)",ticks=list(at=c(56,58,60,62,64,65,66,68,70))),
               x=list(rotate=0, 
                      An_rainn=list(lab="Annual Precipitation (mm)",ticks=list(at=c(0,1.8,2.0,2.2,2.4,2.6,2.8,3.0,3.2))))))

ggplot(MydataA, aes(y=Weightn,x=An_rainn))+geom_smooth(method=loess)

### An_temp
ModWAntemp <- glmmTMB(Weightn ~ An_tempn,
                     data = MydataA)
summary(ModWAntemp)
Anova(ModWAntemp)
AIC(ModWAntemp)

exp(-1.1290) #exp(Estimate)

plot(predictorEffect("An_tempn", ModWAntemp))

plot(predictorEffects(ModWAntemp), main="",
     rug=TRUE,lines=list(col="black"),
     axes=list(y=list(lab="Bodyweight (kg)",ticks=list(at=c(56,58,60,62,64,65,66,68,70))),
               x=list(rotate=0, 
                      An_tempn=list(lab="Annual temperature (Degrees Celsius)",ticks=list(at=c(0,8.0,8.5,9.0,9.5,10.0,10.5,11.0,11.5))))))

ggplot(MydataA, aes(y= Weightn,x=An_tempn))+geom_smooth(method=loess)

### Foragen
ModWforage <- glmmTMB(Weightn ~ Foragen,
                      data = MydataA)
summary(ModWforage)
Anova(ModWforage)
AIC(ModWforage)

exp(0.2043) #exp(Estimate)

plot(predictorEffect("Foragen", ModWforage))

plot(predictorEffects(ModWforage), main="",
     rug=TRUE,lines=list(col="black"), 
     axes=list(y=list(lab="Bodyweight (kg)",ticks=list(at=c(56,58,60,62,63,64,65,66,68,70))),
               x=list(rotate=0, 
                      Foragen=list(lab="Available foraging habitat (km2)",ticks=list(at=c(62,64,66,68,70))))))

ggplot(MydataA, aes(y=Weightn,x=Foragen))+geom_smooth(method=loess) 

### Nmotor_recn
ModWnmotor <- glmmTMB(Weightn ~ Nmotor_recn,
                      data = MydataA)
summary(ModWnmotor)
Anova(ModWnmotor)
AIC(ModWnmotor)

exp(-2.0890) #exp(Estimate)

plot(predictorEffect("Nmotor_recn", ModWnmotor))

plot(predictorEffects(ModWnmotor), main="",
     rug=TRUE,lines=list(col="black"),
     axes=list(y=list(lab="Bodyweight (kg)",ticks=list(at=c(54,56,58,60,62,64,66,68,70))),
               x=list(rotate=0, 
                      Nmotor_recn=list(lab="Non-motorized recreation",ticks=list(at=c(-1.5,-1.0,-0.5,0.0,0.5,1.0,1.5,2.0))))))

ggplot(MydataA, aes(y=Weightn,x=Nmotor_recn))+geom_smooth(method=loess)

### Vehicle
ModWvehicle <- glmmTMB(Weightn ~ Vehiclef,
                       data = MydataA)
summary(ModWvehicle)
Anova(ModWvehicle)
AIC(ModWvehicle)

exp(-0.6280) #exp(Estimate)

plot(predictorEffect("Vehiclef", ModWvehicle))

#------------------------------- Analysis -------------------------------------

# Check for correlations between variables 
cor(MydataA$Agen,MydataA$Weightn) #Age en weight correleren niet, 
#0.357399
cor(MydataA$SQRT_Agen,MydataA$Weightn)
#0.4311722

# Global model 
ModW1<- glmmTMB(Weightn ~ Agen + Agen_sqn + sqrt(D_RDn)+ sqrt(D_RD3n) + An_rainn + An_tempn +  Foragen + Vehiclef + Nmotor_recn, REML = FALSE,
                data = MydataA)
summary(ModW1)
Anova(ModW1)
AIC(ModW1)  
nrow(MydataA) #261

#Groups   Name        Variance  Std.Dev. 
#Year     (Intercept) 8.027e-07 0.0008959
#Residual             4.116e+01 6.4155000

# Year is removed #

### Drop 1 

ModW0 <- glmmTMB(Weightn ~ Vehiclef + Nmotor_recn, REML = FALSE,
                 data = MydataA)

stepAIC(ModW1, direction="both", scope = list(lower = ModW0))

# topmodel stepAIC = Weightn ~ Weightn ~ Agen + Agen_sqn + sqrt(D_RDn) + sqrt(D_RD3n) + An_rainn + Foragen+ Vehiclef + Nmotor_recn
# Final AIC = 1731.2162

ModW3<- lmer(Weightn ~ poly(Agen, degree = 2, raw = TRUE) + sqrt(D_RDn) + sqrt(D_RD3n) + 
               Rainn + Vehiclef + Foragen + Nmotor_recn + (1|Year), REML = FALSE,
             data = MydataA)

summary(ModW3)
drop1(ModW3)

# Model A 
ModW1A<- glmmTMB(Weightn ~ Agen + Agen_sqn + sqrt(D_RDn) + sqrt(D_RD3n) + An_rainn + An_tempn + Foragen + Vehiclef + Nmotor_recn, REML = FALSE,
                 data = MydataA)
drop1(ModW1A)

# Model B 
ModW1B<- glmmTMB(Weightn ~ Agen + Agen_sqn + sqrt(D_RDn) + sqrt(D_RD3n) + An_rainn + Foragen + Vehiclef + Nmotor_recn, REML = FALSE,
                 data = MydataA)
drop1(ModW1B)

# Model C 
ModW1C<- glmmTMB(Weightn ~ Agen + Agen_sqn + sqrt(D_RD3n) + An_rainn + Foragen + Vehiclef + Nmotor_recn, REML = FALSE,
                 data = MydataA)
drop1(ModW1C)

# Model D 
ModW1D<- glmmTMB(Weightn ~ Agen + Agen_sqn + Foragen + Vehiclef + Nmotor_recn + (1|Year), REML = FALSE,
                 data = MydataA)
drop1(ModW1D)

# Model E 
ModW1E<- glmmTMB(Weightn ~ Agen + Agen_sqn + Vehiclef + Nmotor_recn + (1|Year), REML = FALSE,
                 data = MydataA)
drop1(ModW1E)

# Final model: Weightn ~ Agen + Agen_sqn + Vehiclef + Nmotor_recn + (1 | Year)
# Final AIC = 1731.2

# Final model weight 
ModW2<- glmmTMB(Weightn ~ poly(Agen, degree = 2, raw = TRUE) + Vehiclef + Nmotor_recn, REML = FALSE,
             data = MydataA)

summary(ModW2)
Anova(ModW2)
AIC(ModW2)  

plot(allEffects(ModW2), pages = 1, lines=list(col="black"), selection = 3)

# Plot final model
plot(predictorEffects(ModW2, residuals=TRUE),main="",
     rug=FALSE,lines=list(col="black"),
     axes=list(y=list(lab="Bodyweight (kg)",ticks=list(at=c(58,60,62,64,66,68))),
               x=list(rotate=0, Nmotor_recn=list(lab= "Non-motorized recreation",ticks=list(at=c(-1,0,1))),
                      Vehiclef=list(lab= "Motorized recreation"), Agen=list(lab= "Age",ticks=list(at=c(5,10,15))))))

r.squaredGLMM(ModW2)

### Quick validation topmodel

resW = simulateResiduals(ModW2)
plot(res, rank=T) 
plotResiduals(res) 
testDispersion(res)  
testZeroInflation(res) 

ModW3<- lmer(Weightn ~ Agen + Agen_sqn + SQRT_D_RDn + SQRT_D_RD3n + An_rainn + Foragen + Vehiclef + Nmotor_recn + (1|Year), REML = TRUE,
             data = MydataA)
summary(ModW3)

#install.packages("predictmeans")
#library(lme4)
#library(lmerTest)
library(predictmeans)

#Cooks distance: 0.10 is highest, so therefore there's no problem 
MydataA$cook <- cooks.distance(inf1)

MydataA$cook <- CookD(ModW3)

inf1 <- influence(ModW2,obs=TRUE)

summary(ModW3)

### Residuals 

resW = simulateResiduals(ModW2)

#Included in model: 

# Age
plotResiduals(resW, form = MydataA$Agen, rank = T)
plotResiduals(resW, form = MydataA$Agen, rank = FALSE)

# Age_sqn
plotResiduals(resW, form = MydataA$Agen_sqn, rank = T)
plotResiduals(resW, form = MydataA$Agen_sqn, rank = FALSE)

# SQRT_D_RDn
plotResiduals(resW, form = MydataA$SQRT_D_RDn, rank = T)
plotResiduals(resW, form = MydataA$SQRT_D_RDn, rank = FALSE)

# SQRT_D_RD3n
plotResiduals(resW, form = MydataA$SQRT_D_RD3n, rank = T)
plotResiduals(resW, form = MydataA$SQRT_D_RD3n, rank = FALSE)

# An_rainn
plotResiduals(resW, form = MydataA$An_rainn, rank = T)
plotResiduals(resW, form = MydataA$An_rainn, rank = FALSE)

# Foragen
plotResiduals(resW, form = MydataA$Foragen, rank = T)
plotResiduals(resW, form = MydataA$Foragen, rank = FALSE)

# Nmotor_recn
plotResiduals(resW, form = MydataA$Nmotor_recn, rank = T)
plotResiduals(resW, form = MydataA$Nmotor_recn, rank = FALSE)

# Vehiclef
plotResiduals(resW, form = MydataA$Vehiclef)

# Not included in model: 

# An_tempn
plotResiduals(resW, form = MydataA$An_tempn, rank = T)
plotResiduals(resW, form = MydataA$An_tempn, rank = FALSE)

# ----------------------------------- END -------------------------------------