#----------------------- Analysis Scaled variables ----------------------------

### Install packages 
#install.packages("readxl")
#install.packages("ggeffects")
#install.packages("MASS")
#install.packages("glmmTMB")
#install.packages("car")
#install.packages("ggplot2")
#install.packages("grid")
#install.packages("animation")
#install.packages("magrittr")
#install.packages("dplyr")
#install.packages("vcd")
#install.packages("plyr")
#install.packages("insight")
#install.packages("parameters")
#install.packages("effects")
#install.packages("MuMIn")

### Load the libraries 
library(readxl)
library(ggeffects)
library(MASS) 
library(glmmTMB)
library(car)
library(ggplot2)
library(grid)
library(animation)
library(ggeffects)
library(magrittr) 
library(plyr)
library(dplyr)    
library(vcd)
library(insight)
library(parameters)
library(effects)
library(MuMIn)

### Set working directory 
setwd("E:/HVHL/BSc_Thesis/R")

### Import the database
Database_annual_Norm_Z <- read_excel("Database_Annual_Norm_Z_FINAL.xlsx") # Database with normal annual data, scaled. 

### View the database
View(Database_annual_Norm_Z)

# -------------------------- 'Year' variables ----------------------------------
MydataYZ <- Database_annual_Norm_Z
nrow(MydataYZ) #31

data_summary <- function(data, varname, groupnames){
  require(plyr)
  summary_func <- function(x, col){
    c(mean = mean(x[[col]], na.rm=TRUE),
      sd = sd(x[[col]], na.rm=TRUE),
      se= sd(x[[col]], na.rm=TRUE)/sqrt(length(x[[col]])),
      seb=sqrt(mean(x[[col]])/(1-mean(x[[col]]))/length(x[[col]])))
  }
  data_sum<-ddply(data, groupnames, .fun=summary_func,
                  varname)
  data_sum <- rename(data_sum, c("mean" = varname))
  return(data_sum)
}

### Convert data to factor or numeric 
# Random factor: 
MydataYZ$Yearf<-as.factor(MydataYZ$Year)                 # year is the random factor

# Dependent variables: 
MydataYZ$Pregnantn<-as.numeric(MydataYZ$Pregnant)        # converted as numeric for weight analysis
MydataYZ$Pregnantf<-as.factor(MydataYZ$Pregnant)         # converted as factor for pregnancy analysis 

# Independent variables: 
MydataYZ$Feedingf<-as.factor(MydataYZ$Feeding_sites)     # absence (0) or presence (1) of feeding sites 
MydataYZ$Vehiclef<-as.factor(MydataYZ$Vehicle_bin)       # number of vehicles (0 = absent, 1 = present)
MydataYZ$ZD_RDn<-as.numeric(MydataYZ$ZD_RD)              # scaled value of the density of red deer 
MydataYZ$ZD_RD1n<-as.numeric(MydataYZ$ZD_RD1)            # scaled value of the density of red deer in former years (t-1)
MydataYZ$ZD_RD2n<-as.numeric(MydataYZ$ZD_RD2)            # scaled value of the density of red deer in former years (t-2)
MydataYZ$ZD_RD3n<-as.numeric(MydataYZ$ZD_RD3)            # scaled value of the density of red deer in former years (t-3)
MydataYZ$ZD_WBn<-as.numeric(MydataYZ$ZD_WB)              # scaled value of the density of wild boar 
MydataYZ$ZD_Cn<-as.numeric(MydataYZ$ZD_C)                # scaled value of the density of cattle 
MydataYZ$ZRD_shotn<-as.numeric(MydataYZ$ZRD_shot)        # scaled value of the number of red deer shot 
MydataYZ$ZTr_coln<-as.numeric(MydataYZ$ZTr_col)          # scaled value of the number of traffic collisions 
MydataYZ$ZAn_tempn<-as.numeric(MydataYZ$ZAn_Temp)        # scaled value of annual temperature 
MydataYZ$ZAn_rainn<-as.numeric(MydataYZ$ZAn_Rain)        # scaled value of annual precipitation 
MydataYZ$ZForagen<-as.numeric(MydataYZ$ZForage)          # scaled value of suitable foraging area 
MydataYZ$ZNmotor_recn<-as.numeric(MydataYZ$ZNmotor_rec)  # scaled value of the number of non-motorized recreationists 

### sqrt-transformed data 
MydataYZ$ZSQRT_D_RDn<-as.numeric(MydataYZ$ZSQRT_D_RD)
MydataYZ$ZSQRT_D_RD2n<-as.numeric(MydataYZ$ZSQRT_D_RD2)
MydataYZ$ZSQRT_D_RD3n<-as.numeric(MydataYZ$ZSQRT_D_RD3)
MydataYZ$ZSQRT_D_WBn<-as.numeric(MydataYZ$ZSQRT_D_WB)
MydataYZ$ZSQRT_D_Cn<-as.numeric(MydataYZ$ZSQRT_D_C)

#------------------------------ Data exploration -------------------------------

### Missing values?
colSums(is.na(MydataYZ))

### Collinearity between predictors (VIF)

# General model (A)
modYZA <- lm(Pregnantn ~ ZSQRT_D_RDn + ZD_RD1n + ZSQRT_D_RD2n + ZSQRT_D_RD3n + ZRD_shotn + ZSQRT_D_Cn + ZTr_coln + ZSQRT_D_WBn + ZAn_rainn + ZAn_tempn + ZForagen + ZNmotor_recn, 
             data = MydataYZ)
vif(modYZA)

# Model B
modYZB <- lm(Pregnantn ~ ZSQRT_D_RDn + ZD_RD1n + ZSQRT_D_RD2n + ZSQRT_D_RD3n + ZRD_shotn + ZTr_coln + ZSQRT_D_WBn + ZAn_rainn + ZAn_tempn + ZForagen + ZNmotor_recn, 
             data = MydataYZ)
vif(modYZB)

# Model C
modYZC <- lm(Pregnantn ~ ZSQRT_D_RDn + ZD_RD1n + ZSQRT_D_RD2n + ZSQRT_D_RD3n + ZTr_coln + ZSQRT_D_WBn + ZAn_rainn + ZAn_tempn + ZForagen + ZNmotor_recn, 
             data = MydataYZ)
vif(modYZC)

# Model D
modYZD <- lm(Pregnantn ~ ZSQRT_D_RDn + ZSQRT_D_RD2n + ZSQRT_D_RD3n + ZTr_coln + ZSQRT_D_WBn + ZAn_rainn + ZAn_tempn + ZForagen + ZNmotor_recn, 
             data = MydataYZ)
vif(modYZD)

# Model E 
modYZE <- lm(Pregnantn ~ ZSQRT_D_RDn + ZSQRT_D_RD2n + ZSQRT_D_RD3n + ZTr_coln + ZAn_rainn + ZAn_tempn + ZForagen + ZNmotor_recn, 
             data = MydataYZ)
vif(modYZE)

### Correlation between independent variables 

#ZAn_tempn x ZAn_Rainn (annual temperature x annual rain)
cor(MydataYZ$ZAn_tempn, MydataYZ$ZAn_rainn)
#0.327818

# ZTr_coln x ZNmotor_recn (traffic collisions x non-motorised recreation)
cor(MydataYZ$ZTr_coln, MydataYZ$ZNmotor_recn)
#0.5922408

#ZSQRT_D_RD2n x ZSQRT_D_RD3n (sqrt_ red deer density(-2) x sqrt red deer density (-3)
cor(MydataYZ$ZSQRT_D_RD2n, MydataYZ$ZSQRT_D_RD3n)
# 0.6772992

# Tr_coln and sqrt(D_RD2n) were removed based on correlations. 

# ---------------- Pregnancy analysis with scaled variables (Z)-----------------

### Set working directory
setwd("E:/BSc Thesis/R")

### Import the database 
Database_animal_Norm_Z <- read_excel("Database_animal_Norm_Z_FINAL.xlsx")

### View the database
View(Database_animal_Norm_Z)

MydataAZ<-Database_animal_Norm_Z
nrow(MydataAZ) 

data_summary <- function(data, varname, groupnames){
  require(plyr)
  summary_func <- function(x, col){
    c(mean = mean(x[[col]], na.rm=TRUE),
      sd = sd(x[[col]], na.rm=TRUE),
      se= sd(x[[col]], na.rm=TRUE)/sqrt(length(x[[col]])),
      seb=sqrt(mean(x[[col]])/(1-mean(x[[col]]))/length(x[[col]])))
  }
  data_sum<-ddply(data, groupnames, .fun=summary_func,
                  varname)
  data_sum <- rename(data_sum, c("mean" = varname))
  return(data_sum)
}

### Transform data to factor or numeric 
# Same variables shown below are also used for the weight analysis 

# Random factor
MydataAZ$Yearf<-as.factor(MydataAZ$Year) 

# Dependent variable 
MydataAZ$Pregnantn<-as.numeric(MydataAZ$Pregnant)
MydataAZ$Pregnantf<-as.factor(MydataAZ$Pregnant)

# Independent variables 
MydataAZ$Feedingf<-as.factor(MydataAZ$Feeding_sites)
MydataAZ$Vehiclef<-as.factor(MydataAZ$Vehicle_bin) 
MydataAZ$ZAgen<-as.numeric(MydataAZ$ZAge)
MydataAZ$Agen<-as.numeric(MydataAZ$Age)
MydataAZ$Weightn<-as.numeric(MydataAZ$Weight)

# Scaled independent variables 
MydataAZ$ZWeightn<-as.numeric(MydataAZ$ZWeight)
MydataAZ$ZD_RDn<-as.numeric(MydataAZ$ZD_RD)
MydataAZ$ZD_RD1n<-as.numeric(MydataAZ$ZD_RD1)
MydataAZ$ZD_RD2n<-as.numeric(MydataAZ$ZD_RD2)
MydataAZ$ZD_RD3n<-as.numeric(MydataAZ$ZD_RD3)
MydataAZ$ZD_WBn<-as.numeric(MydataAZ$ZD_WB)
MydataAZ$ZD_Cn<-as.numeric(MydataAZ$ZD_C)
MydataAZ$ZRD_shotn<-as.numeric(MydataAZ$ZRD_shot)
MydataAZ$ZTr_coln<-as.numeric(MydataAZ$ZTr_col)
MydataAZ$ZAn_tempn<-as.numeric(MydataAZ$ZAn_Temp)
MydataAZ$ZAn_rainn<-as.numeric(MydataAZ$ZAn_Rain)
MydataAZ$ZForagen<-as.numeric(MydataAZ$ZForage)
MydataAZ$ZNmotor_recn<-as.numeric(MydataAZ$ZNmotor_rec)

# Sqrt tranformed variables
MydataAZ$ZSQRT_D_RDn<-as.numeric(MydataAZ$ZSQRT_D_RD)
MydataAZ$ZSQRT_D_RD2n<-as.numeric(MydataAZ$ZSQRT_D_RD2)
MydataAZ$ZSQRT_D_RD3n<-as.numeric(MydataAZ$ZSQRT_D_RD3)
MydataAZ$ZSQRT_D_WBn<-as.numeric(MydataAZ$ZSQRT_D_WB)
MydataAZ$ZSQRT_D_Cn<-as.numeric(MydataAZ$ZSQRT_D_C)
MydataAZ$ZSQRT_Agen <- as.numeric(MydataAZ$ZSQRT_Age)

MydataAZ$ZAgen_sqn <- MydataAZ$ZAgen^2

#------------------------------ Data exploration -------------------------------

### Missing values?
colSums(is.na(MydataAZ))

### Relationships Y vs X
# Relation predictors and dependent variable passage
# Simple logistic regression (passage ~ predictor) and  corresponding (loess+errorbar) 

### ZSQRT_Agen
ModPZAge <- glmmTMB(Pregnantf ~ ZSQRT_Agen,
                    family = "binomial",
                    data = MydataAZ)
summary(ModPZAge)
Anova(ModPZAge)
AIC(ModPZAge)

exp(-0.01755) #exp(Estimate)

plot(predictorEffect("ZSQRT_Agen", ModPZAge))

plot(predictorEffects(ModPZAge), main="",
     rug=TRUE,lines=list(col="black"), 
     axes=list(y=list(lab="Pregnancy rate",ticks=list(at=c(0.70,0.75,0.80,0.85,0.90,0.95))),
               x=list(rotate=0, 
                      ZSQRT_Agen=list(lab=" Z sqrt Age (years)",ticks=list(at=c(-1,0,1,2))))))

ggplot(MydataAZ, aes(y=Pregnantn,x=ZSQRT_Agen))+geom_smooth(method=loess) 

### ZWeightn
ModPZweight <- glmmTMB(Pregnantf ~ ZWeightn,
                       family = "binomial",
                       data = MydataAZ)                                                                                        
summary(ModPZweight)
Anova(ModPZweight)
AIC(ModPZweight)

exp(0.9728 ) #exp(Estimate)

plot(predictorEffect("ZWeightn", ModPZweight))

plot(predictorEffects(ModPZweight), main="",
     rug=TRUE,lines=list(col="black"), 
     axes=list(y=list(lab="Pregnancy rate",ticks=list(at=c(0,0.1,0.2,0.3,0.4,0.5,0.6,0.7,0.8,0.9,0.99))),
               x=list(rotate=0, 
                      ZWeightn=list(lab="Z Bodyweight (kg)",ticks=list(at=c(-2,-1,0,1,2))))))

ggplot(MydataAZ, aes(y=Pregnantn,x=ZWeightn))+geom_smooth(method=loess)

### ZSQRT_D_RDn
ModDPZreddeer <- glmmTMB(Pregnantf ~ ZSQRT_D_RDn,
                        family = "binomial",
                        data = MydataAZ)
summary(ModDPZreddeer)
Anova(ModDPZreddeer)
AIC(ModDPZreddeer)

exp(-0.0303 ) #exp(Estimate)

plot(predictorEffect("ZSQRT_D_RDn", ModDPZreddeer))

plot(predictorEffects(ModDPZreddeer), main="",
     rug=TRUE,lines=list(col="black"), 
     axes=list(y=list(lab="Pregnancy rate",ticks=list(at=c(0.65,0.70,0.75,0.80,0.85,0.90,0.96))),
               x=list(rotate=0, 
                      ZSQRT_D_RDn=list(lab="Z Density Red Deer",ticks=list(at=c(-2,-1,0,1,2))))))

ggplot(MydataAZ, aes(y=Pregnantn,x=ZSQRT_D_RDn))+geom_smooth(method=loess) 

### ZSQRT_D_RD3n
ModDPZreddeer3 <- glmmTMB(Pregnantf ~ ZSQRT_D_RD3n,
                         family = "binomial",
                         data = MydataAZ)
summary(ModDPZreddeer3)
Anova(ModDPZreddeer3)
AIC(ModDPZreddeer3)

exp(0.06866 ) #exp(Estimate)

plot(predictorEffect("ZSQRT_D_RD3n", ModDPZreddeer3))

plot(predictorEffects(ModDPZreddeer3), main="",
     rug=TRUE,lines=list(col="black"), 
     axes=list(y=list(lab="Pregnancy rate",ticks=list(at=c(0.65,0.70,0.75,0.80,0.85,0.90,0.95,0.97))),
               x=list(rotate=0, 
                      ZSQRT_D_RD3n=list(lab="Z Density Red Deer t-3",ticks=list(at=c(-2,-1,0,1,2))))))

ggplot(MydataAZ, aes(y=Pregnantn,x=ZSQRT_D_RD3n))+geom_smooth(method=loess)

### ZAn_rainn
ModPZAn_rain <- glmmTMB(Pregnantf ~ ZAn_rainn,
                     family = "binomial",
                     data = MydataAZ)
summary(ModPZAn_rain)
Anova(ModPZAn_rain)
AIC(ModPZAn_rain)

exp(-0.3313) #exp(Estimate)

plot(predictorEffect("ZAn_rainn", ModPZAn_rain))

plot(predictorEffects(ModPZAn_rain), main="",
     rug=TRUE,lines=list(col="black"), 
     axes=list(y=list(lab="Pregnancy rate",ticks=list(at=c(0.65,0.70,0.75,0.80,0.85,0.90,0.96))),
               x=list(rotate=0, 
                      ZAn_rainn=list(lab="Z Annual precipitation (mm)",ticks=list(at=c(-2,-1,0,1,2))))))

ggplot(MydataAZ, aes(y=Pregnantn,x=ZAn_rainn))+geom_smooth(method=loess) 

### ZAn_temp
ModPZAn_temp <- glmmTMB(Pregnantf ~ ZAn_tempn,
                      family = "binomial",
                      data = MydataAZ)
summary(ModPZAn_temp)
Anova(ModPZAn_temp)
AIC(ModPZAn_temp)

exp(-0.3270) #exp(Estimate)

plot(predictorEffect("ZAn_tempn", ModPZAn_temp))

plot(predictorEffects(ModPZAn_temp), main="",
     rug=TRUE,lines=list(col="black"), 
     axes=list(y=list(lab="Pregnancy rate",ticks=list(at=c(0.65,0.70,0.75,0.80,0.85,0.90,0.97))),
               x=list(rotate=0, 
                      ZAn_tempn=list(lab="Z Annual temperature (Degrees Celsius)",ticks=list(at=c(-2,-1,0,1,2))))))

ggplot(MydataAZ, aes(y=Pregnantn,x=ZAn_tempn))+geom_smooth(method=loess) 

### ZForagen
ModPZForage <- glmmTMB(Pregnantf ~ ZForagen,
                       family = "binomial",
                       data = MydataAZ)
summary(ModPZForage)
Anova(ModPZForage)
AIC(ModPZForage)

exp(0.5530) #exp(Estimate)

plot(predictorEffect("ZForagen", ModPZForage))

plot(predictorEffects(ModPZForage), main="",
     rug=TRUE,lines=list(col="black"), 
     axes=list(y=list(lab="Pregnancy rate",ticks=list(at=c(0.5,0.6,0.7,0.8,0.9,0.97))),
               x=list(rotate=0, 
                      ZForagen=list(lab="Z Available foraging habitat",ticks=list(at=c(-2,-1,0,1,2))))))

ggplot(MydataAZ, aes(y=Pregnantn,x=ZForagen))+geom_smooth(method=loess) 

### ZNmotor_recn
ModPZNmotor <- glmmTMB(Pregnantf ~ ZNmotor_recn,
                       family = "binomial",
                       data = MydataAZ)
summary(ModPZNmotor)
Anova(ModPZNmotor)
AIC(ModPZNmotor)

exp(-0.7250) #exp(Estimate)

plot(predictorEffect("ZNmotor_recn", ModPZNmotor))

plot(predictorEffects(ModPZNmotor), main="",
     rug=TRUE,lines=list(col="black"), 
     axes=list(y=list(lab="Pregnancy rate",ticks=list(at=c(0.40,0.50,0.60,0.70,0.80,0.90,0.96))),
               x=list(rotate=0, 
                      ZNmotor_recn=list(lab="Z Non-motorized recreation",ticks=list(at=c(-2,-1,0,1,2))))))

ggplot(MydataAZ, aes(y=Pregnantn,x=ZNmotor_recn))+geom_smooth(method=loess) 

### Vehicle
ModPvehicle <- glmmTMB(Pregnantf ~ Vehiclef,
                       family = "binomial",
                       data = MydataAZ)
summary(ModPvehicle)
Anova(ModPvehicle)
AIC(ModPvehicle)

exp(-0.01506 ) #exp(Estimate)

### Feedingf
ModPFeeding <- glmmTMB(Pregnantf ~ Feedingf,
                       family = "binomial",
                       data = MydataAZ)
summary(ModPFeeding)
Anova(ModPFeeding)
AIC(ModPFeeding)

exp(1.1921 ) #exp(Estimate)

# ---------------------- Testing Putman's interactions ------------------------

### Interaction ZSQRT_D_RDn x ZSQRT_Agen
ModPZRD_Age <- glmmTMB(Pregnantf ~ ZSQRT_D_RDn*ZSQRT_Agen,
                      family = "binomial",
                      data = MydataAZ)
summary(ModPZRD_Age)
Anova(ModPZRD_Age)
AIC(ModPZRD_Age)

exp(0.146732) #exp(Estimate)

plot(allEffects(ModPZRD_Age), pages = 1)

### Interaction ZSQRT_D_RDn x ZWeightn 
ModPZRD_Weight <- glmmTMB(Pregnantf ~ ZSQRT_D_RDn*ZWeightn,
                         family = "binomial",
                         data = MydataAZ)
summary(ModPZRD_Weight)
Anova(ModPZRD_Weight)
AIC(ModPZRD_Weight)

exp(0.1060) #exp(Estimate)

plot(allEffects(ModPZRD_Weight), pages = 1)

### Interaction ZSQRT_Agen x ZWeigthn 
ModPZAge_Weight <- glmmTMB(Pregnantf ~ ZSQRT_Agen*ZWeightn,
                          family = "binomial",
                          data = MydataAZ)
summary(ModPZAge_Weight)
Anova(ModPZAge_Weight)
AIC(ModPZAge_Weight)

exp(-0.4044) #exp(Estimate)

plot(allEffects(ModPZAge_Weight), pages = 1)

# ------------------------------ Data analysis ---------------------------------

### Global model
ModPZ1<- glmmTMB(Pregnantf ~ ZSQRT_Agen + ZWeightn + ZSQRT_D_RDn + ZSQRT_D_RD3n + ZAn_rainn + ZAn_tempn + ZForagen + Vehiclef + ZNmotor_recn, REML = FALSE,
                 family = "binomial",
                 data = MydataAZ)

summary(ModPZ1)
Anova(ModPZ1)
AIC(ModPZ1)  

model_parameters(ModPZ1, exponentiate = TRUE)

ModPZ0 <- glmmTMB(Pregnantf ~ Vehiclef + ZNmotor_recn,REML = FALSE,
                  family = "binomial",
                  data = MydataAZ)

stepAIC(ModPZ1, direction="both", scope = list(lower = ModPZ0))

#Topmodel = Pregnantf ~ ZSQRT_Agen + ZWeightn + Vehiclef1 + ZNmotor_recn
#AIC = 173.59

### Drop 1 

# Model A 
ModPZ1A<- glmmTMB(Pregnantf ~ ZSQRT_Agen + ZWeightn + ZSQRT_D_RDn + ZSQRT_D_RD3n + ZAn_rainn + ZAn_tempn + ZForagen + Vehiclef + ZNmotor_recn, REML = FALSE,
                  family = "binomial",
                  data = MydataAZ)
drop1(ModPZ1A)

# Model B 
ModPZ1B<- glmmTMB(Pregnantf ~ ZSQRT_Agen + ZWeightn + ZSQRT_D_RDn + ZAn_rainn + ZAn_tempn + ZForagen + Vehiclef + ZNmotor_recn, REML = FALSE,
                  family = "binomial",
                  data = MydataAZ)
drop1(ModPZ1B)

# Model C 
ModPZ1C<- glmmTMB(Pregnantf ~ ZSQRT_Agen + ZWeightn + ZAn_rainn + ZAn_tempn + ZForagen + Vehiclef + ZNmotor_recn, REML = FALSE,
                  family = "binomial",
                  data = MydataAZ)
drop1(ModPZ1C)

# Model D
ModPZ1D<- glmmTMB(Pregnantf ~ ZSQRT_Agen + ZWeightn + ZAn_rainn + ZForagen + Vehiclef + ZNmotor_recn, REML = FALSE,
                  family = "binomial",
                  data = MydataAZ)
drop1(ModPZ1D)

# Model E 
ModPZ1E<- glmmTMB(Pregnantf ~ ZSQRT_Agen + ZWeightn + ZForagen + Vehiclef + ZNmotor_recn, REML = FALSE,
                  family = "binomial",
                  data = MydataAZ)
drop1(ModPZ1E)

# Model F 
ModPZ1F<- glmmTMB(Pregnantf ~ ZSQRT_Agen + ZWeightn + Vehiclef + ZNmotor_recn, REML = FALSE,
                  family = "binomial",
                  data = MydataAZ)
drop1(ModPZ1F)

# Topmodel = Pregnantf ~ ZSQRT_Agen + ZWeightn + Vehiclef + ZNmotor_recn
# Final AIC = 173.59

### Final model Pregnancy
ModPZ2<- glmmTMB(Pregnantf ~ ZSQRT_Agen + ZWeightn + Vehiclef + ZNmotor_recn, REML = FALSE,
                 family = "binomial",
                 data = MydataAZ)

ModPZ2a<- glm(Pregnantf ~ ZSQRT_Agen + ZWeightn + Vehiclef + ZNmotor_recn,
                 family = "binomial",
                 data = MydataAZ)
summary(ModPZ2a)
Anova(ModPZ2)
AIC(ModPZ2)  
nrow(MydataPZ)

model_parameters(ModPZ2, exponentiate = TRUE)

plot(allEffects(ModPZ2), pages = 1)

plot(allEffects(ModPZ2),add.data= TRUE, selection = 2, main ="",  
     colors = "black", rug = TRUE,
     xlab="Z Bodyweight (kg)",
     axes=list(y=list(lab="Pregnancy rate",ticks=list(at=c(0,0.1,0.3,0.5,0.7,0.9,0.99)))))

plot(allEffects(ModPZ2),add.data= TRUE, selection = 4, main ="",  
     colors = "black", rug = TRUE,
     xlab="Z Non-motorized recreation",
     axes=list(y=list(lab="Pregnancy rate",ticks=list(at=c(0.0,1,0.3,0.5,0.7,0.9,0.98)))))

r.squaredGLMM(ModPZ2)

### Quick validation of Topmodel 

# install.packages("DHARMa")
library(DHARMa)

resPZ = simulateResiduals(ModPZ2)
plot(res, rank=T) 
plotResiduals(res) 
testDispersion(res)  
testZeroInflation(res) 

### Residuals 

resPZ = simulateResiduals(ModPZ2)

# Included in model: 

# ZSQRT_Agen
plotResiduals(resPZ, form = MydataAZ$ZSQRT_Agen, rank = T)
plotResiduals(resPZ, form = MydataAZ$ZSQRT_Agen, rank = FALSE)

# ZWeightn: 
plotResiduals(resPZ, form = MydataAZ$ZWeightn, rank = T)
plotResiduals(resPZ, form = MydataAZ$ZWeightn, rank = FALSE)

# Vehiclef
plotResiduals(resPZ, form = MydataAZ$Vehiclef)

# Nmotor_recn
plotResiduals(resPZ, form = MydataAZ$ZNmotor_recn, rank = T)
plotResiduals(resPZ, form = MydataAZ$ZNmotor_recn, rank = FALSE)

# Not included in model: 

# ZSQRT_D_RDn
plotResiduals(resPZ, form = MydataAZ$ZSQRT_D_RDn, rank = T)
plotResiduals(resPZ, form = MydataAZ$ZSQRT_D_RDn, rank = FALSE)

# ZSQRT_D_RD3n
plotResiduals(resPZ, form = MydataAZ$ZSQRT_D_RD3n, rank = T)
plotResiduals(resPZ, form = MydataAZ$ZSQRT_D_RD3n, rank = FALSE)

# ZAn_rainn
plotResiduals(resPZ, form = MydataAZ$ZAn_rainn, rank = T)
plotResiduals(resPZ, form = MydataAZ$ZAn_rainn, rank = FALSE)

# ZAn_tempn
plotResiduals(resPZ, form = MydataAZ$ZAn_tempn, rank = T)
plotResiduals(resPZ, form = MydataAZ$ZAn_tempn, rank = FALSE)

# ZForagen
plotResiduals(resPZ, form = MydataAZ$ZForagen, rank = T)
plotResiduals(resPZ, form = MydataAZ$ZForagen, rank = FALSE)

# ---------------- Weight analysis with scaled variables (Z)-----------------

# --------------------------- Data exploration --------------------------------
### Relationships Y vs X
# Relation predictors and dependent variable passage
# Simple logistic regression (passage ~ predictor) and  corresponding (loess+errorbar) 

### ZAgen
ModWZAge <- glmmTMB(Weightn ~ poly(ZAgen,degree=2,raw=TRUE)+(1|Year),
                    data = MydataAZ)

summary(ModWZAge)
Anova(ModWZAge)
AIC(ModWZAge)

exp(-2.9179) #exp(Estimate)

plot(predictorEffect("ZAgen", ModWZAge))

plot(predictorEffects(ModWZAge), main="",
     rug=TRUE,lines=list(col="black"), 
     axes=list(y=list(lab="Bodyweight (kg)",ticks=list(at=c(40,45,50,55,60,65,70,75,80,85))),
               x=list(rotate=0, 
                      ZAgen=list(lab="Z Age (years)",ticks=list(at=c(-2,-1,0,1,2))))))

ggplot(MydataAZ, aes(y=Weightn,x=ZAgen))+geom_smooth(method=loess) 

### ZSQRT_D_RDn
ModDWZreddeer <- glmmTMB(Weightn ~ ZSQRT_D_RDn+(1|Year),
                        data = MydataAZ)
summary(ModDWZreddeer)
Anova(ModDWZreddeer)
AIC(ModDWZreddeer)

exp(-1.3516) #exp(Estimate)

plot(predictorEffect("ZSQRT_D_RDn", ModDWZreddeer))

plot(predictorEffects(ModDWZreddeer), main="",
     rug=TRUE,lines=list(col="black"), 
     axes=list(y=list(lab="Bodyweight (kg)",ticks=list(at=c(54,56,58,60,62,64,66))),
               x=list(rotate=0, 
                      ZSQRT_D_RDn=list(lab="Z sqrt Density red deer",ticks=list(at=c(-2,-1,0,1,2))))))

ggplot(MydataAZ, aes(y=Weightn,x=ZSQRT_D_RDn))+geom_smooth(method=loess) 

### ZSQRT_D_RD3n
ModDWZreddeer3 <- glmmTMB(Weightn ~ ZSQRT_D_RD3n+(1|Year),
                         data = MydataAZ)
summary(ModDWZreddeer3)
Anova(ModDWZreddeer3)
AIC(ModDWZreddeer3)

exp(0.1165) #exp(Estimate)

plot(predictorEffect("ZSQRT_D_RD3n", ModDWZreddeer3))

plot(predictorEffects(ModDWZreddeer3), main="",
     rug=TRUE,lines=list(col="black"), 
     axes=list(y=list(lab="Bodyweight (kg)",ticks=list(at=c(55,56,57,58,59,60,61,62,63,64,65,66))),
               x=list(rotate=0, 
                      ZSQRT_D_RD3n=list(lab="Z sqrt Density red deer t-3",ticks=list(at=c(-2,-1,0,1,2))))))

ggplot(MydataAZ, aes(y=Weightn,x=ZSQRT_D_RD3n))+geom_smooth(method=loess)

### ZAn_rain
ModWZAn_rain <- glmmTMB(Weightn ~ ZAn_rainn+(1|Year),
                     data = MydataAZ)
summary(ModWZAn_rain)
Anova(ModWZAn_rain)
AIC(ModWZAn_rain)

exp(-1.3221) #exp(Estimate)

plot(predictorEffect("ZAn_rainn", ModWZAn_rain))

plot(predictorEffects(ModWZAn_rain), main="",
     rug=TRUE,lines=list(col="black"), 
     axes=list(y=list(lab="Bodyweight (kg)",ticks=list(at=c(56,58,60,62,64,65,66,68,70))),
               x=list(rotate=0, 
                      ZAn_rainn=list(lab="Z Annual Precipitation (mm)",ticks=list(at=c(-2,-1,0,1,2))))))

ggplot(MydataAZ, aes(y=Weightn,x=ZAn_rainn))+geom_smooth(method=loess)

### ZAn_tempn
ModWZAn_temp <- glmmTMB(Weightn ~ ZAn_tempn+(1|Year),
                      data = MydataAZ)
summary(ModWZAn_temp)
Anova(ModWZAn_temp)
AIC(ModWZAn_temp)

exp(-0.9975) #exp(Estimate)

plot(predictorEffect("ZAn_tempn", ModWZAn_temp))

plot(predictorEffects(ModWZAn_temp), main="",
     rug=TRUE,lines=list(col="black"),
     axes=list(y=list(lab="Bodyweight (kg)",ticks=list(at=c(56,58,60,62,64,65,66,68,70))),
               x=list(rotate=0, 
                      ZAn_tempn=list(lab="Z Annual temperature (Degrees Celsius)",ticks=list(at=c(-2,-1,0,1,2))))))

ggplot(MydataAZ, aes(y=Weightn,x=ZAn_tempn))+geom_smooth(method=loess)

### ZForagen
ModWZforage <- glmmTMB(Weightn ~ ZForagen+(1|Year),
                       data = MydataAZ)
summary(ModWZforage)
Anova(ModWZforage)
AIC(ModWZforage)

exp(0.5410) #exp(Estimate)

plot(predictorEffect("ZForagen", ModWZforage))

plot(predictorEffects(ModWZforage), main="",
     rug=TRUE,lines=list(col="black"), 
     axes=list(y=list(lab="Bodyweight (kg)",ticks=list(at=c(56,58,60,62,63,64,65,66,68,70))),
               x=list(rotate=0, 
                      ZForagen=list(lab="Z Available foraging habitat (km2)",ticks=list(at=c(-2,-1,0,1,2))))))

ggplot(MydataAZ, aes(y=Weightn,x=ZForagen))+geom_smooth(method=loess)

### ZNmotor_recn
ModWZnmotor <- glmmTMB(Weightn ~ ZNmotor_recn+(1|Year),
                       data = MydataAZ)
summary(ModWZnmotor)
Anova(ModWZnmotor)
AIC(ModWZnmotor)

exp(-2.0861) #exp(Estimate)

plot(predictorEffect("ZNmotor_recn", ModWZnmotor))

plot(predictorEffects(ModWZnmotor), main="",
     rug=TRUE,lines=list(col="black"),
     axes=list(y=list(lab="Bodyweight (kg)",ticks=list(at=c(54,56,58,60,62,64,66,68,70))),
               x=list(rotate=0, 
                      ZNmotor_recn=list(lab="Z Non-motorized recreation",ticks=list(at=c(-2,-1,0,1,2))))))

ggplot(MydataAZ, aes(y=Weightn,x=ZNmotor_recn))+geom_smooth(method=loess)

### ZVehicle
ModWZvehicle <- glmmTMB(Weightn ~ Vehiclef+(1|Year),
                        data = MydataAZ)

summary(ModWZvehicle)
Anova(ModWZvehicle)
AIC(ModWZvehicle)

exp(-0.3810) #exp(Estimate)

plot(predictorEffect("Vehiclef", ModWZvehicle))

#------------------------------- Analysis -------------------------------------

# Global model 
ModWZ1<- glmmTMB(Weightn ~ ZAgen + ZAgen_sqn + ZSQRT_D_RDn + ZSQRT_D_RD3n + ZAn_rainn + ZAn_tempn + ZForagen + Vehiclef + ZNmotor_recn + (1|Year), REML = FALSE,
                 data = MydataAZ)
summary(ModWZ1)
Anova(ModWZ1)
AIC(ModWZ1)  
nrow(MydataWZ) 

ModWZ0 <- glmmTMB(Weightn ~ Vehiclef + ZNmotor_recn,REML = FALSE,
                  data = MydataAZ)

stepAIC(ModWZ1, direction="both", scope = list(lower = ModWZ0))

#Topmodel stepAIC = Weightn ~ poly(ZAgen, degree = 2, raw = TRUE) + ZSQRT_RDn + ZSQRT_RD3n + ZAn_rainn +  
#ZForagen + Vehiclef + ZNmotor_recn

#Final AIC = 1731.2

### Drop 1 

# Model A
ModWZ1A<- glmmTMB(Weightn ~ ZAgen + ZAgen_sqn + ZSQRT_D_RDn + ZSQRT_D_RD3n + ZAn_rainn + ZAn_tempn + ZForagen  +Vehiclef + ZNmotor_recn + (1|Year), REML = FALSE,
                  data = MydataAZ)
drop1(ModWZ1A)

# Model B 
ModWZ1B<- glmmTMB(Weightn ~ ZAgen + ZAgen_sqn + ZSQRT_D_RDn + ZSQRT_D_RD3n + ZAn_rainn + ZForagen  +Vehiclef + ZNmotor_recn + (1|Year), REML = FALSE,
                  data = MydataAZ)
drop1(ModWZ1B)

# Model c 
ModWZ1C<- glmmTMB(Weightn ~ ZAgen + ZAgen_sqn + ZSQRT_D_RD3n + ZAn_rainn + ZForagen  +Vehiclef + ZNmotor_recn + (1|Year), REML = FALSE,
                  data = MydataAZ)
drop1(ModWZ1C)

# Model D 
ModWZ1D<- glmmTMB(Weightn ~ ZAgen + ZAgen_sqn + ZAn_rainn + ZForagen + Vehiclef + ZNmotor_recn + (1|Year), REML = FALSE,
                  data = MydataAZ)
drop1(ModWZ1D)

# Model E 
ModWZ1E<- glmmTMB(Weightn ~ ZAgen + ZAgen_sqn + ZAn_rainn + Vehiclef + ZNmotor_recn + (1|Year), REML = FALSE,
                  data = MydataAZ)
drop1(ModWZ1E)

# Topmodel = Weightn ~ ZAgen + ZAgen_sqn + ZAn_rainn + Vehiclef + ZNmotor_recn + (1 | Year)
# Final AIC = 1730.8

# Final model weight
ModWZ2<- glmmTMB(Weightn ~ poly(ZAgen,degree=2,raw=TRUE) + ZAn_rainn + Vehiclef + ZNmotor_recn + (1 | Year), REML = TRUE, 
                 dat = MydataAZ)

summary(ModWZ2)
Anova(ModWZ2)
AIC(ModWZ2)  
nrow(MydataAZ)

plot(allEffects(ModWZ2), pages = 1)

r.squaredGLMM(ModWZ2)

### Quick validation topmodel 

resWZ = simulateResiduals(ModWZ2)
plot(res, rank=T) 
plotResiduals(res) 
testDispersion(res) 
testZeroInflation(res) 

### Residuals 

resWZ = simulateResiduals(ModWZ2)

# Included in model: 

# ZAge
plotResiduals(resWZ, form = MydataAZ$ZAgen, rank = T)
plotResiduals(resWZ, form = MydataAZ$ZAgen, rank = FALSE)

# ZAge_sqn
plotResiduals(resWZ, form = MydataAZ$ZAgen_sqn, rank = T)
plotResiduals(resWZ, form = MydataAZ$ZAgen_sqn, rank = FALSE)

# ZAn_rainn
plotResiduals(resWZ, form = MydataAZ$ZAn_rainn, rank = T)
plotResiduals(resWZ, form = MydataAZ$ZAn_rainn, rank = FALSE)

# Vehiclef
plotResiduals(resWZ, form = MydataAZ$Vehiclef)

# Nmotor_recn
plotResiduals(resWZ, form = MydataAZ$ZNmotor_recn, rank = T)
plotResiduals(resWZ, form = MydataAZ$ZNmotor_recn, rank = FALSE)

# Not included in model: 

# ZSQRT_D_RDn
plotResiduals(resWZ, form = MydataAZ$ZSQRT_D_RDn, rank = T)
plotResiduals(resWZ, form = MydataAZ$ZSQRT_D_RDn, rank = FALSE)

# ZSQRT_D_RD3n
plotResiduals(resWZ, form = MydataAZ$ZSQRT_D_RD3n, rank = T)
plotResiduals(resWZ, form = MydataAZ$ZSQRT_D_RD3n, rank = FALSE)

# ZAn_tempn
plotResiduals(resWZ, form = MydataAZ$ZAn_tempn, rank = T)
plotResiduals(resWZ, form = MydataAZ$ZAn_tempn, rank = FALSE)

# ZForagen
plotResiduals(resWZ, form = MydataAZ$ZForagen, rank = T)
plotResiduals(resWZ, form = MydataAZ$ZForagen, rank = FALSE)

#-------------- Standardized coefficient direct effect, pregnancy -------------- 

# Extract linear beta
summary(ModPZ2)
Beta.glm <- summary(ModPZ2a)$coefficients[3, 1]
Beta.glm

# Extract predicted values on the link scale
preds <- predict(ModPZ2a, type = "link")

# Compute sd of error variance using theoretical variances
sd.y.LT <- sqrt(var(preds) + pi^2/3)
sd.y.LT
# Compute sd of x
sd.x <- sd(MydataAZ$ZWeightn)

Beta.glm * sd.x / sd.y.LT
## [1] 0.0007202086

# Extract linear beta
summary(ModPZ2a)
Beta.glm <- summary(ModPZ2a)$coefficients[5, 1]
Beta.glm

# Extract predicted values on the link scale
preds <- predict(ModPZ2a, type = "link")

# Compute sd of error variance using theoretical variances
sd.y.LT <- sqrt(var(preds) + pi^2/3)
sd.y.LT
# Compute sd of x
sd.x <- sd(MydataAZ$ZNmotor_recn)

Beta.glm * sd.x / sd.y.LT

-0.1471*0.5619432
#totale effect
-0.194463-0.08266184
#percentage indirecte effect of total effect
-0.08266184/-0.2771248*100


#-------------- Standardized coefficient direct effect, weight ----------------- 

summary(ModWZ2)

# Obtain the raw coefficient from the coefficient table
B <- summary(ModWZ2)$coefficients[2,2]
B <- fixef(ModWZ2)$ZNmotor_recn
B <- -1.4995
# Compute the standard deviation of the independent variable
sd.x <- sd(MydataAZ$ZNmotor_recn)
sd.x
mean(MydataAZ$ZNmotor_recn)

# Compute the standard deviation of the dependent variable
sd.y <- sd(MydataAZ$Weightn)

# Scale Beta
B.sdscaled <- B * sd.x/sd.y
B.sdscaled
#The argument for standardization based on standard deviations is standardize = "scale":
  
coefs(model, standardize = "scale")
##   Response Predictor Estimate Std.Error DF Crit.Value P.Value Std.Estimate 
## 1        y        x1   0.0011    0.1014 98      0.011  0.9912       0.0011

# Compare to hand-calculated value
B.sdscaled
## [1] 0.001113655

# ----------------------------------- END -------------------------------------